@@ -652,6 +652,10 @@ fn test_double_replicator_restart() {
         db.start_replicator(
             "ws://127.0.0.1:4984/demo/",
             ReplicatorAuthentication::None,
+            |collection, doc_id, rev_id, rev_flags, _body| {
+                println!("Pull filter: {collection} , {doc_id}, {rev_id}, {rev_flags:?}");
+                true
+            },
             move |repl_state| {
                 println!("repl_state changed: {:?}", repl_state);
                 if let ReplicatorState::Idle = repl_state {
